package org.s4s.gui.views;

import com.vaadin.navigator.ViewChangeListener;
import com.vaadin.ui.Alignment;
import com.vaadin.ui.Button;
import com.vaadin.ui.HorizontalLayout;
import com.vaadin.ui.Notification;
import com.vaadin.ui.Panel;
import com.vaadin.ui.UI;
import com.vaadin.ui.VerticalLayout;
import java.util.logging.Level;
import java.util.logging.Logger;
import org.s4s.dao.ProductDAO;
import org.s4s.exceptions.DAOException;
import org.s4s.modell.dto.Product;
import org.s4s.modell.dto.Shop;
import org.s4s.modell.dto.Warenkorb;
import org.s4s.process.control.ProductSearch;
import org.s4s.services.util.Roles;
import org.s4s.services.util.Views;

/**
 *
 * @author Holger
 */
public class ArtikeldetailsView extends TemplateView {

    private Warenkorb warenkorb = Warenkorb.getInstance();
    private Product product = new Product();
    private Shop shop = new Shop();
    private final ProductDAO products = ProductSearch.getInstance();
    private VerticalLayout verticalLayout = new VerticalLayout();

    @Override
    public void enter(ViewChangeListener.ViewChangeEvent event) {
        if (event.getParameters() != null) {
            // split at "/", add each part as a label
            String str = event.getParameters();
            int id = Integer.parseInt(str);

            this.setUp(id);
        } else {
            Notification.show(null, "Kein Artikel ausgewählt!", Notification.Type.HUMANIZED_MESSAGE);
            UI.getCurrent().getNavigator().navigateTo(Views.WELCOME);
        }
    }

    public void setUp(int id) {
        try {
            product = products.getProductById(id);
            shop = products.getProductOwner(product);
            HorizontalLayout horizontalLayout = new HorizontalLayout();
            Panel p = new Panel("Name: " + product.getName());
            Panel p1 = new Panel("Beschreibung: " + product.getDescription());
            Panel p2 = new Panel("Preis: " + product.getPrice());
            Panel p3 = new Panel("Anbieter: " + shop.getName());
            verticalLayout.addComponent(p);
            verticalLayout.setComponentAlignment(p, Alignment.MIDDLE_LEFT);
            verticalLayout.addComponent(p1);
            verticalLayout.setComponentAlignment(p1, Alignment.MIDDLE_LEFT);
            verticalLayout.addComponent(p2);
            verticalLayout.setComponentAlignment(p2, Alignment.MIDDLE_LEFT);
            verticalLayout.addComponent(p3);
            verticalLayout.setComponentAlignment(p3, Alignment.MIDDLE_LEFT);
            verticalLayout.addComponent(horizontalLayout);

            if (session.getAttribute(Roles.CURRENTUSER) != null) {
                System.out.println(session.getAttribute(Roles.CURRENTUSER));
                Button addButton = new Button("Hinzufügen");

                addButton.addClickListener((event) -> {
                    if (warenkorb.contains(product)) {
                        Notification.show(null, product.getName() + " befindet sich schon in Ihrem Warenkorb!",
                                Notification.Type.WARNING_MESSAGE);
                    } else {
                        warenkorb.add(product);
                        Notification.show(null, product.getName() + " wurde in den Warenkorb hinzugefügt!",
                                Notification.Type.WARNING_MESSAGE);
                        System.out.println(warenkorb.getAnzahl());
                    }
                });
                verticalLayout.addComponent(addButton);
                verticalLayout.setComponentAlignment(addButton, Alignment.TOP_RIGHT);
            }

            this.addComponent(verticalLayout);
        } catch (DAOException ex) {
            Logger.getLogger(ArtikeldetailsView.class.getName()).log(Level.SEVERE, null, ex);
        }
        super.setUpFooterAndHeader(verticalLayout);
    }
}
