package org.s4s.gui.views;

import com.vaadin.navigator.ViewChangeListener;
import com.vaadin.server.FontAwesome;
import com.vaadin.shared.ui.label.ContentMode;
import com.vaadin.ui.*;
import com.vaadin.ui.themes.ValoTheme;
import java.util.logging.Level;
import java.util.logging.Logger;
import org.s4s.dao.KundenDAO;
import org.s4s.exceptions.DAOException;
import org.s4s.exceptions.NoSuchUserOrPassword;
import org.s4s.process.control.LoginControl;
import org.s4s.services.util.Views;

/**
 *
 * @author Holger
 */
public class LoginView extends TemplateView {

    private final KundenDAO kundenDAO = new LoginControl();

    @Override
    public void enter(ViewChangeListener.ViewChangeEvent event) {
        this.setUp();
    }

    public void setUp() {
        setSizeFull();
        HorizontalLayout titleLayout = new HorizontalLayout();
        final Label lblTitel = new Label("Anmelden");

        titleLayout.addComponent(lblTitel);
        titleLayout.setComponentAlignment(lblTitel, Alignment.MIDDLE_CENTER);

        final TextField userLogin = new TextField();
        userLogin.setCaption("Login-Name: ");
        final PasswordField passwordField = new PasswordField();
        passwordField.setCaption("Passwort: ");

        VerticalLayout layout = new VerticalLayout();
        layout.addComponent(titleLayout);
        layout.setComponentAlignment(titleLayout, Alignment.TOP_CENTER);
        lblTitel.setStyleName("LoginViewContainerTitle");
        titleLayout.setStyleName("LoginViewContainerTitelLayout");
        layout.addComponent(userLogin);
        layout.addComponent(passwordField);

        Label label = new Label("&nbsp", ContentMode.HTML);
        layout.addComponent(label);

        HorizontalLayout hLay = new HorizontalLayout();

        Button button = new Button("Login", FontAwesome.BEER);
        Button buttonReg = new Button("Registrieren", FontAwesome.BEER);
        Button abbruch = new Button("Abbruch");
        abbruch.setIcon(FontAwesome.STOP_CIRCLE);
        abbruch.addStyleName(ValoTheme.BUTTON_LINK);
        hLay.addComponent(button);
        Label lbl = new Label("&nbsp", ContentMode.HTML);
        hLay.addComponent(lbl);
        hLay.addComponent(buttonReg);
        layout.addComponent(label);
        layout.addComponent(hLay);
        
        VerticalLayout box = new VerticalLayout();
        HorizontalLayout horSpacer = new HorizontalLayout();
        horSpacer.addComponent(layout);
        box.addComponent(horSpacer);
        horSpacer.setComponentAlignment(layout, Alignment.MIDDLE_CENTER);

        box.setComponentAlignment(horSpacer, Alignment.MIDDLE_CENTER);
        
        HorizontalLayout abbruchSpacer = new HorizontalLayout();
        abbruchSpacer.addComponent(abbruch);
        Label lb = new Label("&nbsp", ContentMode.HTML);
        box.addComponent(lb);
        box.addComponent(abbruchSpacer);
        
        box.setComponentAlignment(abbruchSpacer, Alignment.MIDDLE_CENTER);
        
        this.addComponent(box);
        this.setComponentAlignment(box, Alignment.MIDDLE_CENTER);
        button.addClickListener((Button.ClickEvent event) -> {
            String login = userLogin.getValue();
            String password = passwordField.getValue();

            try {
                kundenDAO.getUserByCredentials(login, password);

            } catch (NoSuchUserOrPassword ex) {
                Notification.show("Fehler", "Login oder Passwort falsch", Notification.Type.ERROR_MESSAGE);
                userLogin.setValue("");
                passwordField.setValue("");
                Logger.getLogger(LoginView.class.getName()).log(Level.SEVERE, null, ex);
            } catch (DAOException ex) {
                Notification.show("Fehler", "interner Fehler", Notification.Type.ERROR_MESSAGE);
                Logger.getLogger(LoginView.class.getName()).log(Level.SEVERE, null, ex);
            }
            // bei Erfolg wird der Navigator angesprochen und man wird in wieder zur Landingpage geführt
            UI.getCurrent().getNavigator().navigateTo(Views.WELCOME);
        });
        horSpacer.setStyleName("LoginViewContainer");

//        layout.addComponent(buttonReg);
        buttonReg.addClickListener((Button.ClickEvent event) -> {
            UI.getCurrent().getNavigator().navigateTo(Views.REGISTRIERUNG);
        });
         abbruch.addClickListener(e -> {
            UI.getCurrent().getNavigator().navigateTo(Views.WELCOME);
        });
    }

}
