package org.s4s.gui.views;

import com.vaadin.data.util.BeanContainer;
import com.vaadin.data.util.BeanItem;
import com.vaadin.event.ItemClickEvent;
import com.vaadin.navigator.ViewChangeListener;
import com.vaadin.ui.Alignment;
import com.vaadin.ui.Button;
import com.vaadin.ui.HorizontalLayout;
import com.vaadin.ui.Notification;
import com.vaadin.ui.Table;
import com.vaadin.ui.UI;
import java.util.HashSet;
import java.util.Set;
import java.util.logging.Level;
import java.util.logging.Logger;
import org.s4s.dao.ProductDAO;
import org.s4s.dao.ShopSearchDAO;
import org.s4s.exceptions.DAOException;
import org.s4s.modell.dto.Product;
import org.s4s.modell.dto.Shop;
import org.s4s.modell.dto.Warenkorb;
import org.s4s.process.control.ProductSearch;
import org.s4s.process.control.ShopSearch;
import org.s4s.services.util.Roles;
import org.s4s.services.util.Views;

/**
 *
 * @author Holger
 */
public class SucheView extends TemplateView {

    private final ProductDAO products = ProductSearch.getInstance();
    private final ShopSearchDAO shops = ShopSearch.getInstance();
    private Product product = null;
    private final Warenkorb warenkorb = Warenkorb.getInstance();
    private final BeanContainer<Integer, Product> data = new BeanContainer<>(Product.class);
    private final Table table = new Table("Products", data);

    @Override
    public void enter(ViewChangeListener.ViewChangeEvent event) {
        this.setUp();
        if (event.getParameters() != null) {
            // split at "/", add each part as a label
            String str = event.getParameters();
            str = str.trim();
            search(str);
        }
    }

    public void setUp() {
        setSizeFull();
        setMargin(true);

        final HorizontalLayout searchLayout = new HorizontalLayout();
        final HorizontalLayout buttonLayout = new HorizontalLayout();
        buttonLayout.addComponent(searchLayout);
        buttonLayout.setComponentAlignment(searchLayout, Alignment.TOP_RIGHT);
        buttonLayout.setSizeFull();
        addComponent(buttonLayout);
        data.setBeanIdProperty("id");
        table.setSizeFull();
        table.setSelectable(true);

        final BeanContainer<Integer, Shop> dataShops = new BeanContainer<>(Shop.class);
        dataShops.setBeanIdProperty("id");
        final Table tableShops = new Table("Shops", dataShops);
        tableShops.setSizeFull();
        Set<Shop> listeShops = new HashSet<>();

        Button detailButton = new Button("Artikeldetails");
        detailButton.addClickListener((event) -> {
            UI.getCurrent().getNavigator().navigateTo(Views.ARTIKELDETAILS + "/" + product.getId());
        });
        searchLayout.addComponent(detailButton);
        searchLayout.setComponentAlignment(detailButton, Alignment.MIDDLE_CENTER);

        if (session.getAttribute(Roles.CURRENTUSER) != null) {
            System.out.println(session.getAttribute(Roles.CURRENTUSER));
            Button addButton = new Button("Hinzufügen");

            addButton.addClickListener((event) -> {
                if (this.product == null) {
                    Notification.show(null, "Bitte Produkt(e) auswählen!", Notification.Type.HUMANIZED_MESSAGE);
                } else {
                    if (warenkorb.contains(product)) {
                        Notification.show(null, product.getName() + " befindet sich schon in Ihrem Warenkorb!",
                                Notification.Type.WARNING_MESSAGE);
                    } else {
                        warenkorb.add(product);
                        Notification.show(null, product.getName() + " wurde in den Warenkorb hinzugefügt!",
                                Notification.Type.WARNING_MESSAGE);
                        System.out.println(warenkorb.getAnzahl());
                    }
                }
            });
            addComponent(addButton);
            setComponentAlignment(addButton, Alignment.MIDDLE_CENTER);
        }
        table.addItemClickListener((ItemClickEvent event) -> {
            BeanItem<Product> productBean = data.getItem(event.getItemId());
            product = productBean.getBean();
        });
        super.setUpFooterAndHeader(searchLayout);
    }

    private void search(String str) {
        data.setBeanIdProperty("id");
        table.setSizeFull();
        table.setSelectable(true);
        Set<Product> liste = new HashSet<>();
        if ("".equals(str)) {
            Notification.show(null, "Bitte gesuchtes Produkt eingeben!", Notification.Type.WARNING_MESSAGE);
        } else {
            addComponent(table);
            try {
                liste.addAll(products.getProductByName(str));
                liste.addAll(products.getProductByDescription(str));
            } catch (DAOException ex) {
                Logger.getLogger(SucheView.class.getName()).log(Level.SEVERE, null, ex);
            }
            data.removeAllItems();
            data.addAll(liste);
            table.setPageLength(table.size());
            table.setVisibleColumns(new Object[]{"name", "description", "price"});
            table.addItemClickListener((ItemClickEvent event) -> {
                BeanItem<Product> productBean = data.getItem(event.getItemId());
                product = productBean.getBean();
                if (event.isDoubleClick()) {
                    UI.getCurrent().getNavigator().navigateTo(Views.ARTIKELDETAILS + "/" + product.getId());
                }
            });
        }
    }
}
