package org.s4s.modell.dto;

import java.util.ArrayList;
import java.util.List;

/**
 *
 * @author Holger
 */
public class Warenkorb {

    private final List<Product> products;
    private static Warenkorb warenkorb;

    public Warenkorb() {
        products = new ArrayList<>();
    }

    public static Warenkorb getInstance() {
        if (warenkorb == null) {
            warenkorb = new Warenkorb();
        }
        return warenkorb;
    }

    public List<Product> inhalt() {
        return products;
    }

    public void add(Product p) {
        if (p == null) {
            throw new NullPointerException("Produkt darf nicht null sein!");
        }
        products.add(p);
    }

    public Product getProduct(int i) {
        return products.get(i);
    }

    public void remove(Product p) {
        if (p == null) {
            throw new NullPointerException("Produkt darf nicht null sein!");
        }
        if (!products.contains(p)) {
            throw new IllegalArgumentException("Das Produkt ist nicht im Warenkorb enthalten!");
        }
        products.remove(p);
    }

    public void clear() {
        products.clear();
    }

    public double sum() {
        return products.stream().mapToDouble(p -> p.getPrice()).sum();
    }

    public boolean contains(Product p) {
        if (p == null) {
            throw new NullPointerException("Produkt darf nicht null sein!");
        }
        return products.contains(p);
    }

    public int getAnzahl() {
        return products.size();
    }

    public void auflisten() {
        products.forEach((p) -> {
            System.out.println(p.getName() + ", " + p.getPrice());
            //System.out.println(p.getName());
        });
    }

    /* public BeanContainer<Integer, Product> ausgabe() {
        final BeanContainer<Integer, Product> data = new BeanContainer<>(Product.class);
        data.setBeanIdProperty("id");
        products.forEach((product) -> {
            data.addBean(product);
        });
        final Table table = new Table("Products", data);
        table.setSizeFull();
        table.setSelectable(true);
        return data;
    }*/
}
